@@ -18,7 +18,7 @@ from ..lib import variant
 from .db import Db, Tag
 from .cvt import StdValueCvt
 from .connection import Connection
-
+from .web import configure_web_args, init_web
 
 class DropProtocol(Protocol):
     def connectionMade(self):
@@ -104,6 +104,7 @@ def main():
         # Args
         arg_parser = argparse.ArgumentParser()
         configure_my_args(arg_parser)
+        configure_web_args(arg_parser)
         configure_arg_parser_for_log(arg_parser)  # let logger add his arguments for later configure_logger() call
         env = arg_parser.parse_args()
 
@@ -136,6 +137,8 @@ def main():
             log.error(ex)
             return 1
 
+        init_web(env, db, reactor, log)
+        
         reactor.run()                                               # pylint: disable=no-member
 
         log.info('GOODBYE')
